@@ -875,7 +875,7 @@ use Win32::PEFile::PEConstants;
 
 push @Win32::PEFile::idataHandler::ISA, 'Win32::PEFile::SectionHandlers';
 Win32::PEFile::idataHandler->register('.idata',
-    qw'getImportNames haveImportEntry');
+    qw'getImportNames getImportNamesArray haveImportEntry');
 
 
 sub uiName {
@@ -902,6 +902,25 @@ sub getImportNames {
 }
 
 
+sub getImportNamesArray {
+    my ($self) = @_;
+    my %dlls;
+
+    return if !exists $self->{DataDir}{'.idata'};
+
+    $self->_parse_idata() if !exists $self->{SecData}{'.idata'};
+
+    my $entries = $self->{SecData}{'.idata'}{Entries};
+
+    for my $dllName (keys %$entries) {
+        my $entry = $entries->{$dllName};
+        $dlls{$dllName} = [@{$entry->{_entries}}];
+    }
+
+    return @{$self->{SecData}{'.idata'}{ByName}};
+}
+
+
 sub haveImportEntry {
     my ($self, $entryPath) = @_;
 
@@ -931,6 +950,7 @@ sub _parse_idata {
     read $peFile, (my $idata), $idataHdr->{size};
 
     my @dirTable;
+    my @nameArray;
 
     $self->{SecData}{'.idata'}{dirTable} = \@dirTable;
     open my $dirFile, '<', \$idata;
@@ -950,11 +970,13 @@ sub _parse_idata {
         my $dllName         = $self->_readNameStr($peFile, $dllNameFileAddr);
         my $entries         = $self->{SecData}{'.idata'}{Entries} ||= {};
 
+        push @nameArray, $dllName;
         $entries->{$dllName} = \%dirEntry;
         $entries->{$dllName}{_entries} =
             $self->_parseImportLUTable($peFile, $dllName);
     }
 
+    $self->{SecData}{'.idata'}{ByName} = \@nameArray;
     close $peFile;
 }
 
